@@ -15,6 +15,7 @@ from typing import (
     Iterator,
     Set,
     Union,
+    Iterable,
 )
 
 import docutils
@@ -236,11 +237,21 @@ def _get_json_schema_files(app: sphinx.application.Sphinx):
     if not include_globs:
         return
 
+    exclude_globs = (
+        app.config.exclude_patterns
+        + app.config.templates_path
+        + sphinx.project.EXCLUDE_PATHS
+    )
+
+    if sphinx.version_info >= (6, 0):
+        yield from sphinx.util.matching.get_matching_files(
+            app.srcdir, include_patterns=include_globs, exclude_patterns=exclude_globs
+        )
+        return
+
+    # Use older predicate-based `get_matching_files`.
     include_re = _globs_to_re(include_globs)
-
-    exclude_paths = app.config.exclude_patterns + app.config.templates_path
-    exclude_re = _globs_to_re(exclude_paths + sphinx.project.EXCLUDE_PATHS)
-
+    exclude_re = _globs_to_re(exclude_globs)
     matching_files = sphinx.util.get_matching_files(
         app.srcdir, (lambda s: exclude_re.fullmatch(s) is not None,)
     )
@@ -330,6 +341,7 @@ def _traverse_sub_schemas(
         obj = schema.get(prop)
         if obj is None:
             return
+        items: Iterable[Tuple[Union[int, str], JsonSchema]]
         if isinstance(obj, list):
             items = enumerate(obj)
         elif isinstance(obj, dict):
@@ -768,11 +780,11 @@ class JsonSchemaDirective(sphinx.directives.ObjectDescription):
                 *self._get_source_info_from_schema_string(source_string),
             )
 
-    def _render_body(self):
+    def _render_body(self) -> List[docutils.nodes.Node]:
         """Renders the body of the schema."""
         schema_data: LoadedSchemaData = getattr(self.env, "json_schema_data")
         schema_node = self._schema_entry.schema
-        result = []
+        result: List[docutils.nodes.Node] = []
 
         if self._rendered_title is not None:
             p = self._rendered_title
