@@ -54,7 +54,9 @@ import {
 import {
   getComponentElement,
   getComponentElements,
+  mountAnnounce,
   mountBackToTop,
+  mountConsent,
   mountContent,
   mountDialog,
   mountHeader,
@@ -168,6 +170,10 @@ const main$ = document$
 /* Set up control component observables */
 const control$ = merge(
 
+  /* Consent */
+  ...getComponentElements("consent")
+    .map(el => mountConsent(el, { target$ })),
+
   /* Dialog */
   ...getComponentElements("dialog")
     .map(el => mountDialog(el, { alert$ })),
@@ -192,9 +198,13 @@ const control$ = merge(
 /* Set up content component observables */
 const content$ = defer(() => merge(
 
+  /* Announcement bar */
+  ...getComponentElements("announce")
+    .map(el => mountAnnounce(el)),
+
   /* Content */
   ...getComponentElements("content")
-    .map(el => mountContent(el, { target$, print$ })),
+    .map(el => mountContent(el, { viewport$, target$, print$ })),
 
   /* Search highlighting */
   ...getComponentElements("content")
